@@ -2,7 +2,7 @@ context("xlsx_sheet_names()")
 
 test_that("sheet names are returned correctly", {
   expect_equal(xlsx_sheet_names("./examples.xlsx")[1:2],
-               c("Sheet1", "1~`!@#$%^&()_-+={}|;\"'<,>.£¹÷¦°"))
+               c("Sheet1", "1~`!@#$%^&()_-+={}|;\"'<,>."))
 })
 
 test_that("sheet name order is correct", {
